@@ -21,7 +21,7 @@ def notify_prerelease_text(project_name, repo, prerelease_version):
     commits = github.commits_between_prerelease_and_latest_release(repo, prerelease_version)
 
     message = f"""
-<!here> *{project_name.upper()} pre-release :rocket:*
+*{project_name.upper()} pre-release :rocket:*
 
 <https://github.com/{repo.full_name}/releases/tag/{prerelease_version}|*{prerelease_version}*>
 {_message_links(commits)}
@@ -83,7 +83,7 @@ def notify_prerelease_error(project_name, repo, version, pulls):
         message_links += f'- <https://github.com/{repo.full_name}/pull/{pull.number}|{pull.title}> ({_get_slack_user_id(pull.user.login)})\n'
 
     text = f"""
-<!here> *{project_name.upper()} pre-release FAILED :warning:*
+*{project_name.upper()} pre-release FAILED :warning:*
 
 <https://github.com/{repo.full_name}/releases/tag/{version}|*{version}*>
 {message_links}
